@@ -1,4 +1,4 @@
-def define_tpu_strategy():
+def define_tpu_strategy(mixed_precision = False, xla_accelerate = False):
 	try:
 		tpu = tf.distribute.cluster_resolver.TPUClusterResolver()
 		print('Running on TPU ', tpu.master())
@@ -14,6 +14,22 @@ def define_tpu_strategy():
 		strategy = tf.distribute.experimental.TPUStrategy(tpu)
 	else:
 		strategy = tf.distribute.get_strategy()
+
+	if mixed_precision:
+		from tensorflow.keras.mixed_precision import experimental as mixed_precision 
+		if tpu: 
+			policy = tf.keras.mixed_precision.experimental.Policy('mixed_bfloat16')
+		else:
+			policy = tf.keras.mixed_precision.experimental.Policy('mixed_float16')
+		mixed_precision.set_policy(policy)
+		print("Mixed precision enabled")
+	else:
+		print("Mixed precision disabled")
+	if xla_accelerate:
+		tf.config.optimizer.set_jit(True)
+		print("Accelerated Linear Algebra enabled")
+	else:
+		print("Accelerated Linear Algebra disabled")
 	
 	return strategy, tpu
 
@@ -198,14 +214,9 @@ def set_parameters(epochs, batch_size_base, GCS_PATH):
 	
 	STEPS_PER_EPOCH = None
 
-if __name__ == "__main__":
-	pass
-else:
-
+if __name__ != "__main__":
 	import tensorflow as tf
-	if tf.__version__ == '2.4.0':
-		pass
-	else:
+	if tf.__version__ != '2.4.0':
 		print("Error! Tensorflow version mismatch")
 		
-	
\ No newline at end of file
+	
